@@ -19,22 +19,12 @@
 #' @param get.tsne boolean Whether to calculate tSNE embedding (default=TRUE) 
 #' @param make.geneknn boolean Whether pre-calculate gene kNN (for gene search) (default=TRUE) 
 #' @return a new 'Pagoda2' object
-#' @examples
-#' \donttest{
-#' ## load count matrix
-#' cm <- p2data::sample_BM1
-#' ## perform basic p2 processing
-#' p2 <- basicP2proc(cm)
-#' }
 #' 
 #' @export 
 basicP2proc <- function(cd, n.cores=1, n.odgenes=3e3, nPcs=100, k=30, perplexity=50, 
   log.scale=TRUE, trim=10, keep.genes=NULL, min.cells.per.gene=0, min.transcripts.per.cell=100, 
   get.largevis=TRUE, get.tsne=TRUE, make.geneknn=TRUE) {
 
-  if (!requireNamespace("p2data", quietly = TRUE)) {
-    stop("Package \"p2data\" needed for the Pagoda2 class to work. This can be installed via a drat repository, using \"install.packages('p2data', repos='https://kharchenkolab.github.io/drat/', type='source')\". Please read the details provided within the README at https://github.com/kharchenkolab/pagoda2.", call. = FALSE)
-  }
   rownames(cd) <- make.unique(rownames(cd))
   ## Basic Processing
   p2 <- Pagoda2$new(cd, n.cores = n.cores, keep.genes = keep.genes, trim=trim, log.scale=log.scale, min.cells.per.gene=min.cells.per.gene, min.transcripts.per.cell=min.transcripts.per.cell)
@@ -77,10 +67,6 @@ basicP2proc <- function(cd, n.cores=1, n.odgenes=3e3, nPcs=100, k=30, perplexity
 #' @export 
 extendedP2proc <- function(p2, organism = 'hs') {
 
-  if (!requireNamespace("p2data", quietly = TRUE)) {
-    stop("Package \"p2data\" needed for the Pagoda2 class to work. This can be installed via a drat repository, using \"install.packages('p2data', repos='https://kharchenkolab.github.io/drat/', type='source')\". Please read the details provided within the README at https://github.com/kharchenkolab/pagoda2.", call. = FALSE)
-  }
-
   if (organism == 'hs') {
     go.env <- p2.generate.human.go(p2)
   } else if (organism == 'mm') {
@@ -201,19 +187,10 @@ webP2proc <- function(p2, additionalMetadata=NULL, title='Pagoda2',
 #'     annotated at that GO term or to one of its child nodes in the GO ontology (default=NULL)
 #' @param eg.alias2eg mappings between common gene symbol identifiers and entrez gene identifiers (default=NULL)
 #' @param min.env.length numeric Minimum environment length (default=5)
-#' @examples
-#' \donttest{
-#' cm <- p2data::sample_BM1
-#' p2 <- basicP2proc(cm)
-#' p2.generate.go(p2, organism='hs')
-#' }
 #' 
 #' @export 
 p2.generate.go <- function(r, organism=NULL, go2all.egs=NULL, eg.alias2eg=NULL, min.env.length=5) {
   
-  if (!requireNamespace("p2data", quietly = TRUE)) {
-    stop("Package \"p2data\" needed for the Pagoda2 class to work. This can be installed via a drat repository, using \"install.packages('p2data', repos='https://kharchenkolab.github.io/drat/', type='source')\". Please read the details provided within the README at https://github.com/kharchenkolab/pagoda2.", call. = FALSE)
-  }
 
   if (is.null(organism) && (is.null(go2all.egs) || is.null(eg.alias2eg))) {
     stop('Either organism or go2all.egs and eg.alias2eg must be specified');
@@ -265,18 +242,9 @@ p2.generate.go <- function(r, organism=NULL, go2all.egs=NULL, eg.alias2eg=NULL,
 #' 
 #' @param r a 'Pagoda2' object
 #' @return a GO environment object
-#' @examples
-#' \donttest{
-#' cm <- p2data::sample_BM1
-#' p2 <- basicP2proc(cm)
-#' p2.generate.dr.go(p2)
-#' }
 #' 
 #' @export
 p2.generate.dr.go <- function(r) {
-  if (!requireNamespace("p2data", quietly = TRUE)) {
-    stop("Package \"p2data\" needed for the Pagoda2 class to work. This can be installed via a drat repository, using \"install.packages('p2data', repos='https://kharchenkolab.github.io/drat/', type='source')\". Please read the details provided within the README at https://github.com/kharchenkolab/pagoda2.", call. = FALSE)
-  }
   p2.generate.go(r, "dr")
 }
 
@@ -285,18 +253,9 @@ p2.generate.dr.go <- function(r) {
 #' 
 #' @param r a 'Pagoda2' object
 #' @return a GO environment object
-#' @examples
-#' \donttest{
-#' cm <- p2data::sample_BM1
-#' p2 <- basicP2proc(cm)
-#' p2.generate.human.go(p2)
-#' }
 #' 
 #' @export
 p2.generate.human.go <- function(r) {
-  if (!requireNamespace("p2data", quietly = TRUE)) {
-    stop("Package \"p2data\" needed for the Pagoda2 class to work. This can be installed via a drat repository, using \"install.packages('p2data', repos='https://kharchenkolab.github.io/drat/', type='source')\". Please read the details provided within the README at https://github.com/kharchenkolab/pagoda2.", call. = FALSE)
-  }
   p2.generate.go(r, "hs")
 }
 
@@ -304,18 +263,9 @@ p2.generate.human.go <- function(r) {
 #' 
 #' @param r a 'Pagoda2' object
 #' @return a GO environment object
-#' @examples
-#' \donttest{
-#' cm <- p2data::sample_BM1
-#' p2 <- basicP2proc(cm)
-#' p2.generate.mouse.go(p2)
-#' }
 #' 
 #' @export 
 p2.generate.mouse.go <- function(r) {
-  if (!requireNamespace("p2data", quietly = TRUE)) {
-    stop("Package \"p2data\" needed for the Pagoda2 class to work. This can be installed via a drat repository, using \"install.packages('p2data', repos='https://kharchenkolab.github.io/drat/', type='source')\". Please read the details provided within the README at https://github.com/kharchenkolab/pagoda2.", call. = FALSE)
-  }
   p2.generate.go(r, "mm")
 }
 
